Django Markdowny — django-markdowny 0.1 documentation

# Django Markdowny

Django Markdowny is a Django template tag application to convert Markdown to HTML.

Unlike other Django/Markdown filters, markdowny supports all of the options available in Python Markdown via Settings.

- Package distribution
- Code repository
- Documentation
- Tests

## Install

    $ pip install django-markdowny

Add to `settings.py`.

    INSTALLED_APPS = [
        # ...
        'markdowny',
    ]

## Usage

Use as a template tag.

    {% load markdowny_tags %}

    {% markdowny %}Hello, world!{% endmarkdowny %}

Or as a template filter.

    {{ post.body|markdowny }}

Result:

    <p>Hello, world!</p>

## Contents

- Install
- Usage
  - HTML
  - Customize with keyword arguments
- Settings
- Documentation
- Tests

## Indices and tables

- Index
- Module Index
- Search Page